C++ API
=======

.. toctree::
   :maxdepth: 2

Pauli
-----
.. doxygenstruct:: fast_pauli::Pauli
    :project: fast_pauli
    :members:

PauliString
-----------
.. doxygenstruct:: fast_pauli::PauliString
    :project: fast_pauli
    :members:


PauliOp
-------
.. doxygenstruct:: fast_pauli::PauliOp
    :project: fast_pauli
    :members:

SummedPauliOp
-------------
.. doxygenstruct:: fast_pauli::SummedPauliOp
    :project: fast_pauli
    :members: